# Filter GLIBC_PRIVATE Requires, see wrappers/dlsym.cpp
%define __filter_GLIBC_PRIVATE 1

%global commit 4a2d21fe836876e95012ffeb682010aef852b97d
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%global date 20201219

Name:           apitrace
Version:        %{date}
Release:        %mkrel 0.git%{shortcommit}.1
Summary:        Tools for tracing OpenGL
Group:          Graphics/Utilities
License:        MIT
URL:            https://apitrace.github.io
Source0:        https://github.com/apitrace/apitrace/archive/%{commit}/%{name}-%{shortcommit}.tar.gz
Source1:        qapitrace.desktop
Source2:        qapitrace.appdata.xml

# Unbundle brotli, gtest
Patch0:         apitrace_unbundle.patch
# Fix build with GCC10
Patch1:         apitrace_gcc10.patch
# Explicitly instantiate template to fix s390x FTBFS
Patch2:         apitrace_template.patch

BuildRequires:  brotli-devel
BuildRequires:  cmake
BuildRequires:  libdwarf-devel
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libprocps)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(snappy)

# scripts/snapdiff.py
Requires:       python3-pillow

# See http://fedoraproject.org/wiki/Packaging:No_Bundled_Libraries#Packages_granted_exceptions
Provides:       bundled(md5-plumb)
# See https://fedorahosted.org/fpc/ticket/429
Provides:       bundled(libbacktrace)
# Modofied http://create.stephan-brumme.com/crc32/, see thirdparty/crc32c/README.md
Provides:       bundled(crc32c)


%description
apitrace consists of a set of tools to:
 * trace OpenGL and OpenGL ES APIs calls to a file
 * replay OpenGL and OpenGL ES calls from a file
 * inspect OpenGL state at any call while retracing
 * visualize and edit trace files


%package gui
Summary:        Graphical frontend for apitrace
Requires:       %{name} = %{version}-%{release}

%description gui
This package contains qapitrace, the Qt5 graphical frontend for apitrace.


%prep
%autosetup -p1 -n %{name}-%{commit}

# Remove bundled libraries, except khronos headers and libbacktrace
rm -rf `ls -1d thirdparty/* | grep -Ev "(khronos|md5|libbacktrace|crc32c)"`


%build
%cmake \
  -DENABLE_STATIC_SNAPPY=OFF
%cmake_build

%install
%cmake_install

# Install doc through %%doc
rm -rf %{buildroot}%{_docdir}/

# Install desktop file
install -Dpm 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/q%{name}.desktop

# Install appdata file
install -Dpm 0644 %{SOURCE2} %{buildroot}%{_datadir}/appdata/q%{name}.appdata.xml


%check
make -C %{_vpath_builddir} check


%files
%doc README.markdown docs/*
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/eglretrace
%{_bindir}/glretrace
%{_libdir}/%{name}/

%files gui
%{_bindir}/q%{name}
%{_datadir}/applications/q%{name}.desktop
%{_datadir}/appdata/q%{name}.appdata.xml


%changelog
* Fri Jan 01 2021 akien <akien> 20201219-0.git4a2d21f.1.mga8
+ Revision: 1667638
- Snapshot 20201219

* Wed Dec 16 2020 umeabot <umeabot> 20200918-0.git1aa8391.2.mga8
+ Revision: 1658132
- Rebuild for new Qt5

* Fri Oct 16 2020 akien <akien> 20200918-0.git1aa8391.1.mga8
+ Revision: 1636461
- Update to 20200918, remove patch that broke libbacktrace test

* Wed Feb 19 2020 umeabot <umeabot> 20200103-0.gitffb366c.3.mga8
+ Revision: 1544337
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 daviddavid <daviddavid> 20200103-0.gitffb366c.2.mga8
+ Revision: 1482899
- rebuild for new procps-ng 3.3.16

* Sun Jan 19 2020 akien <akien> 20200103-0.gitffb366c.1.mga8
+ Revision: 1481484
- Sync with current master branch (20200103)
+ wally <wally>
- build with new cmake macros

* Wed Apr 03 2019 akien <akien> 20190318-0.git2696613.1.mga7
+ Revision: 1385474
- Adapt to Mageia packaging policy, simplify
- Use date as version, upstream doesn't want to do releases anymore
- Update to 20190318 / 2696613
- import apitrace from Fedora Rawhide

